### SC Compression

Version 0.5.3
-

### Tools:
- Decompressor
- Compressor

### Supported compressions:
- LZMA
- SC
- SCLZ
- SIG
- ZSTD

TestPyPi - https://test.pypi.org/project/sc-compression/ <br>
PyPi - https://pypi.org/project/sc-compression/
